@@ -2,8 +2,8 @@
 
 __author__ = """Qin Yu"""
 __email__ = 'qinyusuain@gmail.com'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
-import refactorguide.settings as settings
+import refactorguide.desgin as desgin
 
-settings.init()
+desgin.init()
